#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*******************************************************************************
#**  This file is part of HgWeb Manager.                                     ***
#**                                                                          ***
#**  Copyright (C) 2014                                                      ***
#**  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Affero General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Affero General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Affero General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************

"""
 IMPORTS
"""
import config
from _app_info import *


try:
	# Configuration values for HgWebManager.
	settings = config.Manager()
except Exception as e:
	import sys

	print >>sys.stderr, 'Settings Error:', e
	exit(1)


def is_hgWeb_user():
	""" Determines if the current running user is the expected HgWeb user.

	 @return Gives true when the user is the expected HgWeb user, false
	  else-wise.
	"""
	import getpass

	# FIXME: This isn't a secure check as it is based upon the environmental variable.
	if settings.HgUser == getpass.getuser():
		return True
	else:
		return False


def __extract_values(args):
	""" Pulls the creation arguments out of the command-line.

	 @param[in] args	The command-line argument processor containing the
					creation argument values.

	 @return A managed repository object.
	"""
	import manrepo

	managed = manrepo.Repository()
	if args.repository:
		managed.StorageName = args.repository

	if args.name:
		managed.DisplayName = args.name

	if args.description:
		managed.Description = args.description

	if args.contact:
		managed.Contact = args.contact
	return managed

def main(args):
	import argparse
	import manager
	import sys

	if not is_hgWeb_user():
		print >>sys.stderr, "Must execute as the Mercurial Web manager."
		exit(1)

	parser = argparse.ArgumentParser(description=DESCRIPTION)
	parser.add_argument("repository", action="store", help='The storage-name of the repository to perform an action upon.')
	parser.add_argument("-a", "--action", action="store", nargs=1, type=str, choices=['create','modify','delete', 'register'], help='Performs an action upon a managed repository.')
	parser.add_argument("-n", "--name", action="store", nargs='?', default=None, help='The display name of the repository.')
	parser.add_argument("-d", "--description", action="store", nargs='?', default=None, help='The description of the repository.')
	parser.add_argument("-c", "--contact", action="store", nargs='?', default=None, help='The contact point of a repository.')
	parser.add_argument("-r", "--rename", action="store", nargs='?', default=None, help='The new storage-name for a repository.')
	parser.add_argument("-i", "--ignore", action="store", nargs='+', default=None, help='The groups to place in an ignore file.')
	args = parser.parse_args()
	repo = __extract_values(args)

	if 'create' == args.action[0]:
		if args.ignore:
			ignores = args.ignore
		else:
			ignores = ['Common']
		if manager.create(repo, ignores):
			exit(0)
		else:
			exit(2)
	elif 'modify' == args.action[0]:
		currentStorageName = repo.StorageName
		if args.rename:
			repo.StorageName = args.rename
		if manager.modify(repo, currentStorageName, args.ignore):
			exit(0)
		else:
			exit(2)
	elif 'delete' == args.action[0]:
		if manager.delete(repo):
			exit(0)
		else:
			exit(2)
	elif 'register' == args.action[0]:
		if manager.register(repo):
			exit(0)
		else:
			exit(2)
	else:
		print >>sys.stderr, "Failure determine action request %s." % args.action
		exit(2)

if __name__ == "__main__":
	import sys

	# Display license
	print "%s %s Copyright (C) %s CodeGNU Solutions" % (LONG_NAME, VERSION, YEARS)
	print "%s comes with ABSOLUTELY NO WARRANTY;" % (SHORT_NAME)
	print "This is free software, and you are welcome to redistribute it"
	print "under certain conditions; see the LICENSE file for details,"
	print "or the Free Software Foundation's AGPL.\n"

	main(sys.argv)
